.. image:: https://github.com/bernhardschaefer/yamlu/actions/workflows/run_tests.yaml/badge.svg
    :alt: Built status
    :target: https://github.com/bernhardschaefer/yamlu/actions/workflows/run_tests.yaml
.. image:: https://img.shields.io/pypi/v/yamlu.svg
    :alt: PyPI-Server
    :target: https://pypi.org/project/yamlu/
.. image:: https://img.shields.io/badge/-PyScaffold-005CA0?logo=pyscaffold
    :alt: Project generated with PyScaffold
    :target: https://pyscaffold.org/

|

yamlu
=====

    yet another machine learning utility library

A longer description of your project goes here...

.. _pyscaffold-notes:

Note
====

This project has been set up using PyScaffold 4.1.1. For details and usage
information on PyScaffold see https://pyscaffold.org/.
